@@ -76,6 +76,9 @@
         }
     }
     multivalue <- any(grepl("\\[|\\]|\\{|\\}", expression))
+    if (length(expression) == 1) {
+        expression <- splitstr(expression)
+    }
     coerced2mv <- FALSE
     if (!identical(snames, "")) {
         checkValid(
